@@ -12,9 +12,9 @@ if(is.null(starting_list)){
 for(j in (length(out_list)+1):max_steps){
 	out_list[[j]]<-addRegime(otree,odata,oldshifts=out_list[[j-1]]$savedshifts,oldfit=out_list[[j-1]]$fit,oldaic=out_list[[j-1]]$aic, alloldaic=out_list[[j-1]]$all_aic,exclude=exclude, aic_threshold=aic_threshold, verbose=verbose,plotaic=plotaic,error_skip=error_skip,sample_shifts=sample_shifts, sample_threshold=sample_threshold)
 	if(save_steps)save(out_list,file=filename)
-	if((out_list[[j]]$aic-out_list[[j-1]]$aic)>aic_threshold)break
+	if((out_list[[j]]$aic-out_list[[j-1]]$aic)>=(aic_threshold))break
 	}
-if((out_list[[j]]$aic-out_list[[j-1]]$aic)>=aic_threshold){
+if((out_list[[j]]$aic-out_list[[j-1]]$aic)>=(aic_threshold)){
 	out_list<-out_list[1:(j-1)]
 	}
 out_list	
